// item.h - John K. Estell - 31 January 2002
// Implementation of an item object. Items are read in from an item data file. 
// The format used in this routine consists of one record per line with the fields:
//
//      startRm endRm pts itemName
//
// where 'startRm' and 'endRm' are integers containing room numbers
// where the item is originally located and where it is to end up,
// 'pts' is an integer showing the number of points scored when item
// is placed in end room.  First non-whitespace that follows up to
// end of line is the name of the item.

// a good addition for C++ implementations would be to implement comparison
// routines that would hide the need to use lowercase versions of item names
// for supporting case-insensitivity... 

#ifndef ITEM_H
#define ITEM_H

#include <string>
#include <vector>
using namespace std;

class Item {
	public:
		Item( string name, int start, int target, int targetValue );
		int getStartingRoom();
		string getItemName();			// used to display name
		string getLowercaseItemName(); // used for string comparisions
		int getTargetRoom();
		int getTargetRoomPoints();
	private:
		int startingRoom;
		string itemName;
		string lowercaseItemName;
		int targetRoom;
		int targetRoomPoints;
};


// auxiliary functions - getItemDataRecords reads the specified data file,
// parses the info, creates a new Item object for each record, and stores 
// a pointer to the object in a vector.  The resultant vector is returned.
vector<Item *> getItemDataRecords( string itemDataFile );

#endif